@@ -154,7 +154,7 @@ static struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Europe"), N_("Netherlands Guilder"), N_("Netherlands"), "NLG", NULL, FALSE },
     { N_("Europe"), N_("New Yugoslavian Dinar"), N_("Serbia and Montenegro"), "YUD", NULL, FALSE },
     { N_("Europe"), N_("Norwegian Krone"), N_("Norway"), "NOK", NULL, TRUE },
-    { N_("Europe"), N_("Polish Zloty"), N_("Poland"), "PLZ", NULL, FALSE },
+    { N_("Europe"), N_("Polish Zloty"), N_("Poland"), "PLZ", NULL, TRUE },
     { N_("Europe"), N_("Portuguese Escudo"), N_("Portugal"), "PTE", NULL, FALSE },
     { N_("Europe"), N_("Pound Sterling"), N_("United Kingdom"), "GBP", "£", TRUE },
     { N_("Europe"), N_("Romanian Leu"), N_("Romania"), "ROL", NULL, TRUE },
@@ -196,6 +196,7 @@ static struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Pacific Ocean"), N_("Tongan Pa'anga"), N_("Tonga"), "TOP", NULL, TRUE },
     { N_("Pacific Ocean"), N_("United States Dollar"), N_("Panama"), "USD", "$", TRUE },
     { N_("Pacific Ocean"), N_("Vanuatu Vatu"), N_("Vanuatu"), "VUV", NULL, TRUE },
+    { N_("Southern America"), N_("Brazilian Real"), N_("Brazil"), "BRL", "R$", TRUE },
     { N_("Southern America"), N_("Chilean Peso"), N_("Chile"), "CLP", NULL, TRUE },
     { N_("Southern America"), N_("Colombian Peso"), N_("Colombia"), "COP", NULL, TRUE },
     { N_("Southern America"), N_("Ecuador Sucre"), N_("Ecuador"), "ECS", NULL, FALSE },
@@ -591,6 +592,7 @@ GtkWidget * new_currency_list ()
 						     NULL);
     column = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), col_offset - 1);
     gtk_tree_view_column_set_clickable (GTK_TREE_VIEW_COLUMN (column), TRUE);
+    gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN (column), TRUE);
 
     cell = gtk_cell_renderer_text_new ();
     col_offset = 
@@ -2233,20 +2235,26 @@ gdouble calcule_montant_devise_renvoi ( gdouble montant_init,
 
 
 /**
- * Return either currency's name or currency's ISO4217 nickname if no
- * name is found.
+ * Return either currency's code or ISO4217 code, or name depending on
+ * what is set.
  *
  * \param devise A pointer to a struct_devise holding currency
  * informations.
  *
- * \return name or ISO4217 name of currency.
+ * \return code or ISO4217 code of currency.
  */
 gchar * devise_name ( struct struct_devise * devise )
 {
     if (devise -> code_devise && (strlen(devise -> code_devise) > 0))
 	return devise -> code_devise;
 
-    return devise -> code_iso4217_devise;
+    if (devise -> code_iso4217_devise && (strlen(devise -> code_iso4217_devise) > 0))
+	return devise -> code_iso4217_devise;
+
+    if (devise -> nom_devise && (strlen(devise -> nom_devise) > 0))
+	return devise -> nom_devise;
+
+    return _("No name");    
 }
 
 
