@@ -15,5 +15,7 @@ gboolean blocage_boites_dialogues ( GtkWidget *dialog, gpointer null );
 gboolean question ( gchar *texte );
 gboolean question_yes_no ( gchar *texte );
 gboolean question_yes_no_hint ( gchar *hint, gchar *text );
+gboolean question_conditional_yes_no ( gchar *texte, int * var );
+gboolean question_conditional_yes_no_hint ( gchar *hint, gchar * text, int * var );
 gchar *demande_texte ( gchar *titre_fenetre, gchar *question );
 gchar * make_hint ( gchar * hint, gchar * text );
