@@ -1874,13 +1874,13 @@ void verification_echeances_a_terme ( void )
 	{
 	    /* tant que cette échéance auto n'est pas arrivée à aujourd'hui, on recommence */
 
-	    while ( pointeur_liste != ancien_pointeur
-		    &&
+	    while ( pointeur_liste != ancien_pointeur &&
 		    g_date_compare ( ECHEANCE_COURANTE -> date, pGDateCurrent ) <= 0 )
 	    {
-		struct structure_operation *operation;
+		struct structure_operation * operation;
+		struct struct_type_ope * type_ope = NULL;
 		gint virement;
-		GSList *pointeur_liste_ventil;
+		GSList *pointeur_liste_ventil, *tmp;
 
 		/* We check if one of the subtransactions of the breakdown of
 		   transaction is a transfer on itself. */
@@ -1917,10 +1917,9 @@ void verification_echeances_a_terme ( void )
 		operation -> mois = ECHEANCE_COURANTE -> mois;
 		operation -> annee = ECHEANCE_COURANTE -> annee;
 
-		operation ->date = g_date_new_dmy ( operation ->jour,
-						    operation ->mois,
-						    operation ->annee);
-
+		operation -> date = g_date_new_dmy ( operation ->jour,
+						     operation ->mois,
+						     operation ->annee);
 
 		operation -> no_compte = ECHEANCE_COURANTE -> compte;
 		operation -> tiers = ECHEANCE_COURANTE -> tiers;
@@ -1990,8 +1989,23 @@ void verification_echeances_a_terme ( void )
 
 
 		operation -> type_ope = ECHEANCE_COURANTE -> type_ope;
-		if ( ECHEANCE_COURANTE -> contenu_type )
+		tmp = g_slist_find_custom ( TYPES_OPES,
+					    GINT_TO_POINTER ( ECHEANCE_COURANTE -> type_ope ),
+					    (GCompareFunc) recherche_type_ope_par_no );
+		if ( tmp )
+		{
+		    type_ope = (struct struct_type_ope *) tmp -> data;
+		}
+		if ( type_ope && type_ope -> numerotation_auto )
+		{
+		    operation -> contenu_type = automatic_numbering_get_new_number ( type_ope );
+		    type_ope -> no_en_cours ++;
+
+		}
+		else if ( ECHEANCE_COURANTE -> contenu_type )
+		{
 		    operation -> contenu_type = ECHEANCE_COURANTE -> contenu_type;
+		}
 
 		operation -> auto_man = ECHEANCE_COURANTE -> auto_man;
 		operation -> imputation = ECHEANCE_COURANTE -> imputation;
@@ -2009,13 +2023,13 @@ void verification_echeances_a_terme ( void )
 
 		ajout_operation ( operation );
 
-		/*   si c'était un virement, on crée une copie de l'opé, on l'ajoute à la liste puis on remplit les relations */
-
-		/* FIXME : le jour où on choisira le type de la contre opération dans les échéances, il faudra changer ici */
+		/*   si c'était un virement, on crée une copie de
+		 *   l'opé, on l'ajoute à la liste puis on remplit
+		 *   les relations */
 		if ( virement )
 		    cree_contre_operation_echeance ( operation,
 						     ECHEANCE_COURANTE -> compte_virement,
-						     operation -> type_ope );
+						     ECHEANCE_COURANTE -> type_contre_ope );
 
 		/* 	si c'était une échéance ventilée, c'est ici qu'on fait joujou */
 
@@ -2114,6 +2128,13 @@ void verification_echeances_a_terme ( void )
 			ancien_pointeur = gsliste_echeances;
 		    pointeur_liste = ancien_pointeur;
 		}
+
+		if ( ! date_suivante_echeance ( ECHEANCE_COURANTE, 
+						g_memdup ( pGDateCurrent,
+							   sizeof ( pGDateCurrent ) ) ) )
+		{
+		    break;
+		}
 	    }
 	}
 	else if ( ! ECHEANCE_COURANTE -> no_operation_ventilee_associee )
@@ -2236,6 +2257,11 @@ GDate *date_suivante_echeance ( struct operation_echeance *echeance,
 	return ( pGDateCurrent );
     }
 
+    if ( ! pGDateCurrent || ! g_date_valid ( pGDateCurrent ) )
+    {
+	return NULL;
+    }
+
     /* périodicité hebdomadaire */
     if ( echeance -> periodicite == 1 )
     {
@@ -2257,24 +2283,34 @@ GDate *date_suivante_echeance ( struct operation_echeance *echeance,
 		g_date_add_years ( pGDateCurrent,
 				   1 );
 	    else
-		/* périodicité perso */
-		if ( !echeance -> intervalle_periodicite_personnalisee )
+	    {
+		if ( ! echeance -> periodicite_personnalisee ||
+		     !g_date_valid(pGDateCurrent) )
 		{
-		    g_date_add_days ( pGDateCurrent,
-				      echeance -> periodicite_personnalisee );
-
-		    /* magouille car il semble y avoir un bug dans g_date_add_days
-		       qui ne fait pas l'addition si on ne met pas la ligne suivante */
-		    g_date_add_months ( pGDateCurrent,
-					0 );
+		    return NULL;
 		}
 		else
-		    if ( echeance -> intervalle_periodicite_personnalisee == 1 )
+		{
+		    /* périodicité perso */
+		    if ( !echeance -> intervalle_periodicite_personnalisee )
+		    {
+			g_date_add_days ( pGDateCurrent,
+					  echeance -> periodicite_personnalisee );
+
+			/* magouille car il semble y avoir un bug dans g_date_add_days
+			   qui ne fait pas l'addition si on ne met pas la ligne suivante */
 			g_date_add_months ( pGDateCurrent,
-					    echeance -> periodicite_personnalisee );
+					    0 );
+		    }
 		    else
-			g_date_add_years ( pGDateCurrent,
-					   echeance -> periodicite_personnalisee );
+			if ( echeance -> intervalle_periodicite_personnalisee == 1 )
+			    g_date_add_months ( pGDateCurrent,
+						echeance -> periodicite_personnalisee );
+			else
+			    g_date_add_years ( pGDateCurrent,
+					       echeance -> periodicite_personnalisee );
+		}
+	    }
 
     if ( echeance -> date_limite
 	 &&
