@@ -26,6 +26,7 @@
 
 #include "devises.h"
 #include "etats_gtktable.h"
+#include "etats_csv.h"
 #include "etats_html.h"
 #include "etats_latex.h"
 #include "etats_affiche.h"
@@ -1482,7 +1483,13 @@ void rafraichissement_etat ( struct struct_etat *etat )
 /*****************************************************************************************************/
 void impression_etat ( struct struct_etat *etat )
 {
+#ifndef _WIN32
     affichage_etat ( etat, &latex_affichage );
+#else
+    html_affichage.to_printer = TRUE;
+    affichage_etat ( etat, &html_affichage );
+    html_affichage.to_printer = FALSE;
+#endif
 }
 
 
@@ -1500,6 +1507,7 @@ void impression_etat_courant ( )
 
 void export_etat_vers_html ( struct struct_etat *etat )
 {
+    html_affichage.to_printer = FALSE;
     affichage_etat ( etat, &html_affichage );
 }
 
@@ -1515,6 +1523,16 @@ void export_etat_courant_vers_html ( )
 }
 
 
+
+void export_etat_courant_vers_csv ( )
+{
+    if ( gtk_notebook_get_current_page ( GTK_NOTEBOOK ( notebook_general)) != 7 )
+	gtk_notebook_set_page ( GTK_NOTEBOOK ( notebook_general), 7 );
+
+    affichage_etat ( NULL, &csv_affichage );
+}
+
+
 /*****************************************************************************************************/
 /* Fonction de classement de la liste */
 /* en fonction du choix du type de classement */
@@ -1547,13 +1565,13 @@ classement_suivant:
 
 	    if ( etat_courant -> utilise_categ )
 	    {
-		if ( operation_1 -> categorie != operation_2 -> categorie )
-		    return ( operation_1 -> categorie - operation_2 -> categorie );
-
-		/*     si  les catégories sont nulles, on doit départager entre virements, pas */
-		/* de categ ou opé ventilée */
-		/* on met en 1er les opés sans categ, ensuite les ventilations et enfin les virements */
+		struct struct_categ * categ1, * categ2;
+		GSList * tmp;
 
+		/* Si les catégories sont nulles, on doit départager
+		 * entre virements, pas de categ ou opé ventilée on
+		 * met en 1er les opés sans categ, ensuite les
+		 * ventilations et enfin les virements */
 		if ( !operation_1 -> categorie )
 		{
 		    if ( operation_1 -> operation_ventilee )
@@ -1578,6 +1596,26 @@ classement_suivant:
 				return ( -1 );
 		    }
 		}
+		if ( ! operation_1 -> categorie || ! operation_2 -> categorie )
+		{
+		    return operation_1 -> categorie - operation_2 -> categorie;
+		}
+
+		tmp = g_slist_find_custom ( liste_struct_categories,
+					    GINT_TO_POINTER ( operation_1 -> categorie ),
+					    ( GCompareFunc ) recherche_categorie_par_no );
+		if ( tmp )
+		    categ1 = tmp -> data;
+
+		tmp = g_slist_find_custom ( liste_struct_categories,
+					    GINT_TO_POINTER ( operation_2 -> categorie ),
+					    ( GCompareFunc ) recherche_categorie_par_no );
+		if ( tmp )
+		    categ2 = tmp -> data;
+
+		if ( operation_1 -> categorie != operation_2 -> categorie )
+		    return g_utf8_collate ( categ1 -> nom_categ, categ2 -> nom_categ );
+
 	    }
 
 	    /*       les catégories sont identiques, passe au classement suivant */
@@ -1595,8 +1633,47 @@ classement_suivant:
 		 &&
 		 etat_courant -> afficher_sous_categ )
 	    {
+		struct struct_sous_categ * scateg1, * scateg2;
+		struct struct_categ * categ1, * categ2;
+		GSList * tmp;
+
+		if ( ! operation_1 -> categorie || ! operation_2 -> categorie )
+		    return operation_1 -> categorie - operation_2 -> categorie;
+
+		if ( ! operation_1 -> sous_categorie || ! operation_2 -> sous_categorie )
+		    return operation_1 -> sous_categorie - operation_2 -> sous_categorie;
+
+		tmp = g_slist_find_custom ( liste_struct_categories,
+					    GINT_TO_POINTER ( operation_1 -> categorie ),
+					    ( GCompareFunc ) recherche_categorie_par_no );
+		if ( tmp )
+		    categ1 = tmp -> data;
+
+		tmp = g_slist_find_custom ( liste_struct_categories,
+					    GINT_TO_POINTER ( operation_2 -> categorie ),
+					    ( GCompareFunc ) recherche_categorie_par_no );
+		if ( tmp )
+		    categ2 = tmp -> data;
+		tmp = g_slist_find_custom ( categ1 -> liste_sous_categ,
+					    GINT_TO_POINTER ( operation_1 -> sous_categorie ),
+					    ( GCompareFunc ) recherche_sous_categorie_par_no );
+		if ( tmp )
+		    scateg1 = tmp -> data;
+
+		if ( operation_1 -> categorie != operation_2 -> categorie )
+		    return g_utf8_collate ( categ1 -> nom_categ, categ2 -> nom_categ );
+
+		if ( ! categ1 -> liste_sous_categ || ! categ2 -> liste_sous_categ )
+		    return categ1 -> liste_sous_categ - categ2 -> liste_sous_categ;
+
+		tmp = g_slist_find_custom ( categ2 -> liste_sous_categ,
+					    GINT_TO_POINTER ( operation_2 -> sous_categorie ),
+					    ( GCompareFunc ) recherche_sous_categorie_par_no );
+		if ( tmp )
+		    scateg2 = tmp -> data;
+		
 		if ( operation_1 -> sous_categorie != operation_2 -> sous_categorie )
-		    return ( operation_1 -> sous_categorie - operation_2 -> sous_categorie );
+		    return ( g_utf8_collate ( scateg1 -> nom_sous_categ, scateg2 -> nom_sous_categ ) );
 	    }
 
 	    /*       les ss-catégories sont identiques, passe au classement suivant */
@@ -1612,8 +1689,26 @@ classement_suivant:
 
 	    if ( etat_courant -> utilise_ib )
 	    {
-		if ( operation_1 -> imputation != operation_2 -> imputation )
+		struct struct_imputation * ib1, * ib2;
+		GSList * tmp;
+
+		if ( !operation_1 -> imputation || !operation_2 -> imputation )
 		    return ( operation_1 -> imputation - operation_2 -> imputation );
+
+		tmp = g_slist_find_custom ( liste_struct_imputation,
+					    GINT_TO_POINTER ( operation_1 -> imputation ),
+					    ( GCompareFunc ) recherche_imputation_par_no );
+		if ( tmp )
+		    ib1 = tmp -> data;
+
+		tmp = g_slist_find_custom ( liste_struct_imputation,
+					    GINT_TO_POINTER ( operation_2 -> imputation ),
+					    ( GCompareFunc ) recherche_imputation_par_no );
+		if ( tmp )
+		    ib2 = tmp -> data;
+
+		if ( ib1 && ib2 && ( ib1 != ib2 ) )
+		    return g_utf8_collate ( ib1 -> nom_imputation, ib2 -> nom_imputation );
 	    }
 
 	    /*       les ib sont identiques, passe au classement suivant */
@@ -1631,8 +1726,50 @@ classement_suivant:
 		 &&
 		 etat_courant -> afficher_sous_ib )
 	    {
-		if ( operation_1 -> sous_imputation != operation_2 -> sous_imputation )
+		struct struct_imputation * ib1, * ib2;
+		struct struct_sous_imputation * sib1, * sib2;
+		GSList * tmp;
+
+		if ( !operation_1 -> imputation || !operation_2 -> imputation )
+		    return ( operation_1 -> imputation - operation_2 -> imputation );
+
+		if ( !operation_1 -> sous_imputation || !operation_2 -> sous_imputation )
 		    return ( operation_1 -> sous_imputation - operation_2 -> sous_imputation );
+
+		tmp = g_slist_find_custom ( liste_struct_imputation,
+					    GINT_TO_POINTER ( operation_1 -> imputation ),
+					    ( GCompareFunc ) recherche_imputation_par_no );
+		if ( tmp )
+		    ib1 = tmp -> data;
+
+		tmp = g_slist_find_custom ( liste_struct_imputation,
+					    GINT_TO_POINTER ( operation_2 -> imputation ),
+					    ( GCompareFunc ) recherche_imputation_par_no );
+		if ( tmp )
+		    ib2 = tmp -> data;
+
+		if ( ib1 -> no_imputation != ib2 -> no_imputation )
+		    return g_utf8_collate ( ib1 -> nom_imputation, ib2 -> nom_imputation );
+
+		if ( ! ib1 -> liste_sous_imputation || ! ib2 -> liste_sous_imputation )
+		    return ib1 -> liste_sous_imputation - ib2 -> liste_sous_imputation;
+
+		tmp = g_slist_find_custom ( ib1 -> liste_sous_imputation,
+					    GINT_TO_POINTER ( operation_1 -> sous_imputation ),
+					    ( GCompareFunc ) recherche_sous_imputation_par_no );
+		if ( tmp )
+		    sib1 = tmp -> data;
+
+		tmp = g_slist_find_custom ( ib2 -> liste_sous_imputation,
+					    GINT_TO_POINTER ( operation_2 -> sous_imputation ),
+					    ( GCompareFunc ) recherche_sous_imputation_par_no );
+		if ( tmp )
+		    sib2 = tmp -> data;
+
+		if ( sib1 && sib2 )
+		    return g_utf8_collate ( sib1 -> nom_sous_imputation, 
+					    sib2 -> nom_sous_imputation );
+		
 	    }
 
 	    /*       les ib sont identiques, passe au classement suivant */
@@ -2454,10 +2591,29 @@ pas_decalage:
 			     !strcmp ( devise_categ_etat -> nom_devise, _("Euro") ))
 			    montant = operation -> montant / devise_operation -> change;
 			else
-			    if ( operation -> une_devise_compte_egale_x_devise_ope )
-				montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+			{
+			    /* s'il n'y a pas de taux de change, utilise le taux courant */
+			    if ( operation -> taux_change )
+			    {
+				if ( operation -> une_devise_compte_egale_x_devise_ope )
+				    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				else
+				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    }
 			    else
-				montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    {
+				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
+				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				    montant = 0;
+				else
+				{
+				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_categ_etat -> change;
+				    else
+					montant = operation -> montant * devise_categ_etat -> change;
+				}
+			    }
+			}
 
 		    montant = ( rint (montant * 100 )) / 100;
 		}
@@ -2489,11 +2645,29 @@ pas_decalage:
 			     !strcmp ( devise_ib_etat -> nom_devise, _("Euro") ))
 			    montant = operation -> montant / devise_operation -> change;
 			else
-			    if ( operation -> une_devise_compte_egale_x_devise_ope )
-				montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+			{
+			    /* s'il n'y a pas de taux de change, utilise le taux courant */
+			    if ( operation -> taux_change )
+			    {
+				if ( operation -> une_devise_compte_egale_x_devise_ope )
+				    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				else
+				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    }
 			    else
-				montant = operation -> montant * operation -> taux_change - operation -> frais_change;
-
+			    {
+				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
+				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				    montant = 0;
+				else
+				{
+				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_categ_etat -> change;
+				    else
+					montant = operation -> montant * devise_categ_etat -> change;
+				}
+			    }
+			}
 		    montant = ( rint (montant * 100 )) / 100;
 		}
 		montant_ib_etat = montant_ib_etat + montant;
@@ -2524,10 +2698,29 @@ pas_decalage:
 			     !strcmp ( devise_tiers_etat -> nom_devise, _("Euro") ))
 			    montant = operation -> montant / devise_operation -> change;
 			else
-			    if ( operation -> une_devise_compte_egale_x_devise_ope )
-				montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+			{
+			    /* s'il n'y a pas de taux de change, utilise le taux courant */
+			    if ( operation -> taux_change )
+			    {
+				if ( operation -> une_devise_compte_egale_x_devise_ope )
+				    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				else
+				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    }
 			    else
-				montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    {
+				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
+				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				    montant = 0;
+				else
+				{
+				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_categ_etat -> change;
+				    else
+					montant = operation -> montant * devise_categ_etat -> change;
+				}
+			    }
+			}
 
 		    montant = ( rint (montant * 100 )) / 100;
 		}
@@ -2573,10 +2766,29 @@ pas_decalage:
 			     !strcmp ( devise_compte_en_cours_etat -> nom_devise, _("Euro") ))
 			    montant = operation -> montant / devise_operation -> change;
 			else
-			    if ( operation -> une_devise_compte_egale_x_devise_ope )
-				montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				{
+			    /* s'il n'y a pas de taux de change, utilise le taux courant */
+			    if ( operation -> taux_change )
+			    {
+				if ( operation -> une_devise_compte_egale_x_devise_ope )
+				    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				else
+				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    }
 			    else
-				montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    {
+				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
+				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				    montant = 0;
+				else
+				{
+				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_categ_etat -> change;
+				    else
+					montant = operation -> montant * devise_categ_etat -> change;
+				}
+			    }
+			}
 
 		    montant = ( rint (montant * 100 )) / 100;
 		}
@@ -2604,10 +2816,29 @@ pas_decalage:
 			 !strcmp ( devise_generale_etat -> nom_devise, _("Euro") ))
 			montant = operation -> montant / devise_operation -> change;
 		    else
-			if ( operation -> une_devise_compte_egale_x_devise_ope )
-			    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
-			else
-			    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			{
+			    /* s'il n'y a pas de taux de change, utilise le taux courant */
+			    if ( operation -> taux_change )
+			    {
+				if ( operation -> une_devise_compte_egale_x_devise_ope )
+				    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				else
+				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    }
+			    else
+			    {
+				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
+				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				    montant = 0;
+				else
+				{
+				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_categ_etat -> change;
+				    else
+					montant = operation -> montant * devise_categ_etat -> change;
+				}
+			    }
+			}
 
 		montant = ( rint (montant * 100 )) / 100;
 	    }
@@ -2637,10 +2868,29 @@ pas_decalage:
 			     !strcmp ( devise_categ_etat -> nom_devise, _("Euro") ))
 			    montant = operation -> montant / devise_operation -> change;
 			else
-			    if ( operation -> une_devise_compte_egale_x_devise_ope )
-				montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				{
+			    /* s'il n'y a pas de taux de change, utilise le taux courant */
+			    if ( operation -> taux_change )
+			    {
+				if ( operation -> une_devise_compte_egale_x_devise_ope )
+				    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				else
+				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    }
 			    else
-				montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    {
+				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
+				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				    montant = 0;
+				else
+				{
+				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_categ_etat -> change;
+				    else
+					montant = operation -> montant * devise_categ_etat -> change;
+				}
+			    }
+			}
 
 		    montant = ( rint (montant * 100 )) / 100;
 		}
@@ -2670,10 +2920,29 @@ pas_decalage:
 			     !strcmp ( devise_categ_etat -> nom_devise, _("Euro") ))
 			    montant = operation -> montant / devise_operation -> change;
 			else
-			    if ( operation -> une_devise_compte_egale_x_devise_ope )
-				montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				{
+			    /* s'il n'y a pas de taux de change, utilise le taux courant */
+			    if ( operation -> taux_change )
+			    {
+				if ( operation -> une_devise_compte_egale_x_devise_ope )
+				    montant = operation -> montant / operation -> taux_change - operation -> frais_change;
+				else
+				    montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    }
 			    else
-				montant = operation -> montant * operation -> taux_change - operation -> frais_change;
+			    {
+				/* ne peut faire la conversion que s'il y a un rapport entre les 2 devises */
+				if ( devise_operation -> no_devise != devise_categ_etat -> no_devise_en_rapport )
+				    montant = 0;
+				else
+				{
+				    if ( devise_categ_etat -> une_devise_1_egale_x_devise_2 )
+					montant = operation -> montant / devise_categ_etat -> change;
+				    else
+					montant = operation -> montant * devise_categ_etat -> change;
+				}
+			    }
+			}
 
 		    montant = ( rint (montant * 100 )) / 100;
 		}
