@@ -385,7 +385,12 @@ void charge_configuration ( void )
 		}
 		if ( !strcmp ( node_print -> name, "printer_name" ) ) {
 		    etat.print_config.printer_name = xmlNodeGetContent (node_print);
+#ifdef _WIN32
+                    // Force to use the prt2prv.exe preview tool
+                    etat.print_config.printer_name = g_strdup("prv2prt.exe");
+#endif
 		}
+                
 		if ( !strcmp ( node_print -> name, "printer_filename" ) ) {
 		    etat.print_config.printer_filename = xmlNodeGetContent (node_print);
 		}
@@ -624,7 +629,7 @@ void raz_configuration ( void )
     buffer_dernier_fichier = g_strdup ( "" );
     etat.sauvegarde_auto = 0;    /* on ne sauvegarde pas automatiquement */
     etat.entree = 1;    /* la touche entree provoque l'enregistrement de l'opération */
-    decalage_echeance = 3;     /* nb de jours avant l'échéance pour prévenir */
+    decalage_echeance = 0;     /* nb de jours avant l'échéance pour prévenir */
     etat.formulaire_toujours_affiche = 0;       /* le formulaire ne s'affiche que lors de l'edition d'1 opé */
     etat.formulaire_echeancier_toujours_affiche = 0;       /* le formulaire ne s'affiche que lors de l'edition d'1 opé */
     etat.affichage_exercice_automatique = 1;        /* l'exercice est choisi en fonction de la date */
@@ -676,7 +681,7 @@ void raz_configuration ( void )
 #ifndef _WIN32
     etat.print_config.printer_name = "lpr";
 #else
-    etat.print_config.printer_name = "gsprint";
+    etat.print_config.printer_name = "prv2prt.exe";
 #endif
     etat.print_config.printer_filename = "";
     etat.print_config.filetype = POSTSCRIPT_FILE;
