@@ -1451,7 +1451,7 @@ void creation_compte_importe ( struct struct_compte_importation *compte_import,
 	    else
 		operation -> type_ope = TYPE_DEFAUT_CREDIT;
 
-	    operation -> contenu_type = itoa ( operation_import -> cheque );
+	    operation -> contenu_type = utils_itoa ( operation_import -> cheque );
 
 	    liste_tmp = TYPES_OPES;
 	    type_choisi = NULL;
@@ -2178,7 +2178,7 @@ struct structure_operation *enregistre_ope_importee ( struct struct_ope_importat
 	else
 	    operation -> type_ope = TYPE_DEFAUT_CREDIT;
 
-	operation -> contenu_type = itoa ( operation_import -> cheque );
+	operation -> contenu_type = utils_itoa ( operation_import -> cheque );
 
 	liste_tmp = TYPES_OPES;
 	type_choisi = NULL;
@@ -2420,7 +2420,7 @@ void pointe_opes_importees ( struct struct_compte_importation *compte_import )
 
 		if ( !operation -> pointe )
 		{
-		    operation -> pointe = 3;
+		    operation -> pointe = TELECHECKED_TRANSACTION;
 
 		    /* si c'est une opé ventilée , on recherche les opé filles pour leur mettre le même pointage que la même */
 
@@ -2436,7 +2436,7 @@ void pointe_opes_importees ( struct struct_compte_importation *compte_import )
 			    ope_fille = liste_ope -> data;
 
 			    if ( ope_fille -> no_operation_ventilee_associee == operation -> no_operation )
-				ope_fille -> pointe = 3;
+				ope_fille -> pointe = TELECHECKED_TRANSACTION;
 
 			    liste_ope = liste_ope -> next;
 			}
@@ -2513,7 +2513,7 @@ void pointe_opes_importees ( struct struct_compte_importation *compte_import )
 
 			if ( !operation -> pointe )
 			{
-			    operation -> pointe = 3;
+			    operation -> pointe = TELECHECKED_TRANSACTION;
 
 			    /* si c'est une opé ventilée, on recherche les opé filles pour leur mettre le même pointage que la même */
 
@@ -2528,7 +2528,7 @@ void pointe_opes_importees ( struct struct_compte_importation *compte_import )
 				    ope_fille = liste_ope -> data;
 
 				    if ( ope_fille -> no_operation_ventilee_associee == operation -> no_operation )
-					ope_fille -> pointe = 3;
+					ope_fille -> pointe = TELECHECKED_TRANSACTION;
 
 				    liste_ope = liste_ope -> next;
 				}
@@ -2738,7 +2738,7 @@ gboolean click_dialog_ope_orphelines ( GtkWidget *dialog,
 
 		    operation = enregistre_ope_importee ( ope_import,
 							  ope_import -> no_compte	);
-		    operation -> pointe = 3;
+		    operation -> pointe = TELECHECKED_TRANSACTION;
 
 		    /* on a enregistré l'opé, on la retire maintenant de la liste et de la sliste */
 
@@ -2760,11 +2760,6 @@ gboolean click_dialog_ope_orphelines ( GtkWidget *dialog,
 		}
 	    }
 
-	    /* s'il n'y a plus rien à enregistrer on vire la boite de dialog */
-
-	    if ( !g_slist_length ( liste_opes_import_celibataires ))
-		gtk_widget_destroy ( dialog );
-
 	    /* on enregistre la nouvelle liste d'opé pour la retrouver plus tard */
 
 	    g_object_set_data ( G_OBJECT ( liste_ope_celibataires ),
@@ -2794,7 +2789,10 @@ gboolean click_dialog_ope_orphelines ( GtkWidget *dialog,
 
 	    modification_fichier ( TRUE );
 
-	    if ( result != GTK_RESPONSE_OK )
+
+	    if ( result != GTK_RESPONSE_OK
+		 &&
+		 g_slist_length ( liste_opes_import_celibataires ))
 		break;
 
 	default:
@@ -2844,6 +2842,7 @@ GtkWidget *onglet_importation (void)
     GtkWidget *hbox;
     GtkWidget *label;
     GtkWidget *bouton;
+    gchar *sTmp;
 
     vbox_pref = new_vbox_with_title_and_icon ( _("Import"),
 					       "files.png" ); 
@@ -2856,13 +2855,16 @@ GtkWidget *onglet_importation (void)
 			 0 );
     gtk_widget_show ( hbox );
 
-    label = gtk_label_new ( _("Search the transaction "));
+    sTmp = POSTSPACIFY(_("Search the transaction"));
+    label = gtk_label_new ( sTmp );
     gtk_box_pack_start ( GTK_BOX ( hbox ),
 			 label,
 			 FALSE,
 			 FALSE,
 			 0 );
     gtk_widget_show ( label );
+    g_free(sTmp);
+    sTmp = NULL;
 
     bouton = gtk_spin_button_new_with_range ( 0.0,
 					      100.0,
@@ -2880,13 +2882,16 @@ GtkWidget *onglet_importation (void)
 			 0 );
     gtk_widget_show ( bouton );
 
-    label = gtk_label_new ( _("days around the date in the imported transaction."));
+    sTmp = PRESPACIFY(_("days around the date in the imported transaction."));
+    label = gtk_label_new ( sTmp );
     gtk_box_pack_start ( GTK_BOX ( hbox ),
 			 label,
 			 FALSE,
 			 FALSE,
 			 0 );
     gtk_widget_show ( label );
+    g_free(sTmp);
+    sTmp = NULL;
 
     if ( !nb_comptes )
     {
