@@ -112,6 +112,10 @@ int main (int argc, char *argv[])
     /* affiche l'onglet opération de l'onglet Affichage des données du 3ème état */
 
 #ifdef _WIN32
+    /* Retrieve exception information and store them under grisbi.rpt file!
+     * see http://jrfonseca.dyndns.org/projects/gnu-win32/software/drmingw/index.html for more information */
+    LoadLibrary("exchndl.dll");
+    
     /* we store the path of the running file to use it for pixmaps, help and locales .... */
     win32_set_app_path(argv[0]);
     /* needed to be able to use the "common" installation of GTK libraries */
