@@ -112,6 +112,7 @@ GtkWidget *init_menus ( GtkWidget *vbox )
 	{menu_name(_("Reports"), _("Clone report"), NULL),   "<CTRL><SHIFT>C", G_CALLBACK (dupliquer_etat ), 0, "<StockItem>", GTK_STOCK_COPY },
 	{menu_name(_("Reports"), _("Print report"), NULL),   NULL, G_CALLBACK ( impression_etat_courant), 0, "<StockItem>", GTK_STOCK_PRINT },
 	{menu_name(_("Reports"), _("Export report as HTML..."), NULL),   NULL, G_CALLBACK ( export_etat_courant_vers_html), 0, "<StockItem>", GTK_STOCK_CONVERT },
+	{menu_name(_("Reports"), _("Export report as CSV..."), NULL),   NULL, G_CALLBACK ( export_etat_courant_vers_csv), 0, "<StockItem>", GTK_STOCK_CONVERT },
 	{menu_name(_("Reports"), "Sep1", NULL),    NULL, NULL, 0, "<Separator>", NULL },
 	{menu_name(_("Reports"), _("Import report file"), NULL),   NULL, G_CALLBACK (importer_etat ), 0, "<StockItem>", GTK_STOCK_CONVERT },
 	{menu_name(_("Reports"), _("Export report file"), NULL),   NULL, G_CALLBACK ( exporter_etat), 0, "<StockItem>", GTK_STOCK_CONVERT },
@@ -216,6 +217,8 @@ void affiche_derniers_fichiers_ouverts ( void )
 {
     gint i;
 
+    efface_derniers_fichiers_ouverts ();
+
     if ( !nb_derniers_fichiers_ouverts )
     {
 	gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
@@ -225,6 +228,11 @@ void affiche_derniers_fichiers_ouverts ( void )
 	return;
     }
 
+    if ( nb_derniers_fichiers_ouverts > nb_max_derniers_fichiers_ouverts )
+    {
+	nb_derniers_fichiers_ouverts = nb_max_derniers_fichiers_ouverts;
+    }
+
     for ( i=0 ; i<nb_derniers_fichiers_ouverts ; i++ )
     {
 	GtkItemFactoryEntry *item_factory_entry;
