@@ -3,7 +3,7 @@
 /* 			classement_liste.c                                    */
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cédric Auger (cedric@grisbi.org)	      */
-/*			2004 Alain Portal (dionysos@grisbi.org) 	      */
+/*			2004 Alain Portal (aportal@univ-montp2.fr)	      */
 /*			http://www.grisbi.org   			      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -406,8 +406,9 @@ gint classement_sliste_par_date_rp ( struct structure_operation *pTransaction1,
     /* si l'opération 1 est rapprochée alors que l'opération 2 ne l'est pas,
        ou si l'opération 1 est pointée et l'opération 2 n'est ni pointée, ni
        rapprochée, alors on dit que l'opération 1 est antérieure */
-    if ( ( pTransaction1 -> pointe == 2 && pTransaction2 -> pointe != 2 )
-	 || ( pTransaction1 -> pointe == 1 && pTransaction2 -> pointe == 0 ))
+    if ( ( pTransaction1 -> pointe == RECONCILED_TRANSACTION && pTransaction2 -> pointe != RECONCILED_TRANSACTION )
+	 || ( pTransaction1 -> pointe == CHECKED_TRANSACTION && pTransaction2 -> pointe != CHECKED_TRANSACTION )
+	 || ( pTransaction1 -> pointe == TELECHECKED_TRANSACTION && pTransaction2 -> pointe != TELECHECKED_TRANSACTION ))
     {
 	sort_result = -1;
     }
@@ -415,8 +416,9 @@ gint classement_sliste_par_date_rp ( struct structure_operation *pTransaction1,
     {
 	/* même raisonnement que ci-dessus, sauf que l'on interverti opération 1
 	   et opération 2 */
-	if ( ( pTransaction2 -> pointe == 2 && pTransaction1 -> pointe != 2 )
-	     || ( pTransaction2 -> pointe == 1 && pTransaction1 -> pointe == 0 ))
+	if ( ( pTransaction2 -> pointe == RECONCILED_TRANSACTION && pTransaction1 -> pointe != RECONCILED_TRANSACTION )
+	     || ( pTransaction2 -> pointe == CHECKED_TRANSACTION && pTransaction1 -> pointe != CHECKED_TRANSACTION )
+	     || ( pTransaction2 -> pointe == TELECHECKED_TRANSACTION && pTransaction1 -> pointe != TELECHECKED_TRANSACTION ))
 	{
 	    sort_result = 1;
 	}
