@@ -35,25 +35,6 @@
 #define PRESPACIFY(s) (g_strconcat ( " ", s, NULL ))
 #define POSTSPACIFY(s) (g_strconcat ( s, " ", NULL ))
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  define _(String) gettext(String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop(String)
-#  else
-#    define N_(String) (String)
-#  endif /* gettext_noop */
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,String) (String)
-#  define dcgettext(Domain,String,Type) (String)
-#  define bindtextdomain(Domain,Directory) (Domain) 
-#endif /* ENABLE_NLS */
-
-
 
 /* variables contenant juste 0 ou 1 */
 
@@ -407,7 +388,7 @@ struct struct_type_ope
     gint signe_type;   /* 0=neutre, 1=débit, 2=crédit */
     gint affiche_entree;    /* par ex pour virement, chèques ... */
     gint numerotation_auto;        /* pour les chèques */
-    gdouble no_en_cours;
+    gint no_en_cours;
     gint no_compte;
 };
 
@@ -624,6 +605,7 @@ struct struct_etat_affichage
     void (* attach_hsep) (int, int, int, int); /** Draw horizontal separator (aka "-")  */
     void (* attach_vsep) (int, int, int, int); /** Draw vertical separator (aka "|") */
     void (* attach_label) (gchar *, gdouble, int, int, int, int, enum alignement, struct structure_operation *); /** Drraw a label with properties  */
+    gboolean to_printer;
 };
 
 
